@@ -1,17 +1,16 @@
 package Pod::Weaver::Config::Finder;
-{
-  $Pod::Weaver::Config::Finder::VERSION = '4.001'; # TRIAL
-}
+# ABSTRACT: the reader for weaver.ini files
+$Pod::Weaver::Config::Finder::VERSION = '4.016'; # TRIAL
 use Moose;
 extends 'Config::MVP::Reader::Finder';
 with 'Pod::Weaver::Config';
-# ABSTRACT: the reader for weaver.ini files
+
+use namespace::autoclean;
 
 sub default_search_path {
   return qw(Pod::Weaver::Config Config::MVP::Reader);
 }
 
-no Moose;
 __PACKAGE__->meta->make_immutable;
 1;
 
@@ -27,7 +26,7 @@ Pod::Weaver::Config::Finder - the reader for weaver.ini files
 
 =head1 VERSION
 
-version 4.001
+version 4.016
 
 =head1 AUTHOR
 
@@ -35,7 +34,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2021 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
