@@ -1,23 +1,28 @@
 package Pod::Weaver::Plugin::EnsurePod5;
-{
-  $Pod::Weaver::Plugin::EnsurePod5::VERSION = '4.001'; # TRIAL
-}
+# ABSTRACT: ensure that the Pod5 translator has been run on this document
+$Pod::Weaver::Plugin::EnsurePod5::VERSION = '4.016'; # TRIAL
 use Moose;
 with 'Pod::Weaver::Role::Preparer';
-# ABSTRACT: ensure that the Pod5 translator has been run on this document
 
 use namespace::autoclean;
-use Moose::Autobox;
 
 use Pod::Elemental::Transformer::Pod5;
 
+#pod =head1 OVERVIEW
+#pod
+#pod This plugin is very, very simple:  it runs the Pod5 transformer on the input
+#pod document and removes any leftover whitespace-only Nonpod elements.  If
+#pod non-whitespace-only Nonpod elements are found, an exception is raised.
+#pod
+#pod =cut
 
 sub _strip_nonpod {
   my ($self, $node) = @_;
 
   # XXX: This is really stupid. -- rjbs, 2009-10-24
-  $node->children->keys->reverse->each_value(sub {
-    my ($i, $para) = ($_, $node->children->[$_]);
+
+  foreach my $i (reverse 0 .. $#{ $node->children }) {
+    my $para = $node->children->[$i];
 
     if ($para->isa('Pod::Elemental::Element::Pod5::Nonpod')) {
       if ($para->content !~ /\S/) {
@@ -28,7 +33,7 @@ sub _strip_nonpod {
     } elsif ($para->does('Pod::Elemental::Node')) {
       $self->_strip_nonpod($para);
     }
-  });
+  }
 }
 
 sub prepare_input {
@@ -42,7 +47,7 @@ sub prepare_input {
   return;
 }
 
-no Moose;
+__PACKAGE__->meta->make_immutable;
 1;
 
 __END__
@@ -57,7 +62,7 @@ Pod::Weaver::Plugin::EnsurePod5 - ensure that the Pod5 translator has been run o
 
 =head1 VERSION
 
-version 4.001
+version 4.016
 
 =head1 OVERVIEW
 
@@ -71,7 +76,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2021 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
