@@ -1,19 +1,35 @@
 package Pod::Weaver::Plugin::SingleEncoding;
-{
-  $Pod::Weaver::Plugin::SingleEncoding::VERSION = '4.001'; # TRIAL
-}
+# ABSTRACT: ensure that there is exactly one =encoding of known value
+$Pod::Weaver::Plugin::SingleEncoding::VERSION = '4.016'; # TRIAL
 use Moose;
 with(
   'Pod::Weaver::Role::Dialect',
   'Pod::Weaver::Role::Finalizer',
 );
-# ABSTRACT: ensure that there is exactly one =encoding of known value
 
 use namespace::autoclean;
-use Moose::Autobox;
 
 use Pod::Elemental::Selectors -all;
 
+#pod =head1 OVERVIEW
+#pod
+#pod The SingleEncoding plugin is a Dialect and a Finalizer.
+#pod
+#pod During dialect translation, it will look for C<=encoding> directives.  If it
+#pod finds them, it will ensure that they all agree on one encoding and remove them.
+#pod
+#pod During document finalization, it will insert an C<=encoding> directive at the
+#pod top of the output, using the encoding previously detected.  If no encoding was
+#pod detected, the plugin's C<encoding> attribute will be used instead.  That
+#pod defaults to UTF-8.
+#pod
+#pod If you want to reject any C<=encoding> directive that doesn't match your
+#pod expectations, set the C<encoding> attribute by hand.
+#pod
+#pod No actual validation of the encoding is done.  Pod::Weaver, after all, deals in
+#pod text rather than bytes.
+#pod
+#pod =cut
 
 has encoding => (
   reader => 'encoding',
@@ -29,6 +45,9 @@ sub translate_dialect {
 
   my $want;
   $want = $self->encoding if $self->_has_encoding;
+  if ($want) {
+    $self->log_debug("enforcing encoding of $want in all pod");
+  }
 
   my $childs = $document->children;
   my $is_enc = s_command([ qw(encoding) ]);
@@ -66,6 +85,7 @@ sub finalize_document {
   my $is_pod = s_command([ qw(pod) ]); # ??
   for (0 .. $#$childs) {
     next if $is_pod->( $childs->[ $_ ] );
+    $self->log_debug('setting =encoding to ' . $self->encoding);
     splice @$childs, $_, 0, $encoding;
     last;
   }
@@ -73,7 +93,7 @@ sub finalize_document {
   return;
 }
 
-no Moose;
+__PACKAGE__->meta->make_immutable;
 1;
 
 __END__
@@ -88,7 +108,7 @@ Pod::Weaver::Plugin::SingleEncoding - ensure that there is exactly one =encoding
 
 =head1 VERSION
 
-version 4.001
+version 4.016
 
 =head1 OVERVIEW
 
@@ -114,7 +134,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2021 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
