@@ -1,15 +1,22 @@
 package Pod::Weaver::Role::Dialect;
-{
-  $Pod::Weaver::Role::Dialect::VERSION = '4.001'; # TRIAL
-}
+# ABSTRACT: something that translates Pod subdialects to standard Pod5
+$Pod::Weaver::Role::Dialect::VERSION = '4.016'; # TRIAL
 use Moose::Role;
 with 'Pod::Weaver::Role::Plugin';
-# ABSTRACT: something that translates Pod subdialects to standard Pod5
 
+use namespace::autoclean;
+
+#pod =head1 IMPLEMENTING
+#pod
+#pod The Dialect role indicates that a plugin will be used to pre-process the input
+#pod Pod document before weaving begins.  The plugin must provide a
+#pod C<translate_dialect> method which will be called with the input hashref's
+#pod C<pod_document> entry.  It is expected to modify the document in place.
+#pod
+#pod =cut
 
 requires 'translate_dialect';
 
-no Moose::Role;
 1;
 
 __END__
@@ -24,7 +31,7 @@ Pod::Weaver::Role::Dialect - something that translates Pod subdialects to standa
 
 =head1 VERSION
 
-version 4.001
+version 4.016
 
 =head1 IMPLEMENTING
 
@@ -39,7 +46,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2021 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
