@@ -1,16 +1,23 @@
 package Pod::Weaver::Section::Leftovers;
-{
-  $Pod::Weaver::Section::Leftovers::VERSION = '4.001'; # TRIAL
-}
+# ABSTRACT: a place to put everything that nothing else used
+$Pod::Weaver::Section::Leftovers::VERSION = '4.016'; # TRIAL
 use Moose;
 with(
   'Pod::Weaver::Role::Section',
   'Pod::Weaver::Role::Finalizer',
 );
-# ABSTRACT: a place to put everything that nothing else used
-
-use Moose::Autobox;
 
+#pod =head1 OVERVIEW
+#pod
+#pod This section plugin is used to designate where in the output sequence all
+#pod unused parts of the input C<pod_document> should be placed.
+#pod
+#pod Other section plugins are expected to remove from the input Pod document any
+#pod sections that are consumed.  At the end of all section weaving, the Leftovers
+#pod section will inject any leftover input Pod into its position in the output
+#pod document.
+#pod
+#pod =cut
 
 use Pod::Elemental::Element::Pod5::Region;
 use Pod::Elemental::Types qw(FormatName);
@@ -36,8 +43,8 @@ sub weave_section {
     format_name => $self->_marker,
     content     => '',
   });
-  
-  $document->children->push($placeholder);
+
+  push @{ $document->children }, $placeholder;
 }
 
 sub finalize_document {
@@ -46,18 +53,18 @@ sub finalize_document {
   my $children = $input->{pod_document}->children;
   $input->{pod_document}->children([]);
 
-  INDEX: for my $i (0 .. $document->children->length - 1) {
+  INDEX: for my $i (0 .. @{ $document->children } - 1) {
     my $para = $document->children->[$i];
     next unless $para->isa('Pod::Elemental::Element::Pod5::Region')
          and    $para->format_name eq $self->_marker;
 
+    $self->log_debug('splicing leftovers back into pod');
     splice @{ $document->children }, $i, 1, @$children;
     last INDEX;
   }
 }
 
 __PACKAGE__->meta->make_immutable;
-no Moose;
 1;
 
 __END__
@@ -72,7 +79,7 @@ Pod::Weaver::Section::Leftovers - a place to put everything that nothing else us
 
 =head1 VERSION
 
-version 4.001
+version 4.016
 
 =head1 OVERVIEW
 
@@ -90,7 +97,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2021 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
